<?php
require_once 'AliZend/Form.php';

class AliForm_Metabox extends AliZend_Form
{
    protected $_postId;

    public function init()
    {
        $this->addElement('checkbox', 'custom', array(
            'label' => 'Use custom settings for this post/page',
        ));

        $this->addElement('text', 'max_links', array(
            'filters' => array(
                'StripNewlines',
                'StringTrim',
                'Digits',
                'Null',
            ),
            'validators' => array(
                'Digits',
            ),
            'label' => 'Maximum links for this post/page'
        ));
    }

    public function isValid($data)
    {
        $custom = isset($data['custom']) && $data['custom'];

        $this->_setCustom($custom);

        if (!$custom) {
            return TRUE;
        }

        return parent::isValid($data);
    }

    public function load()
    {
        $meta = Ali_Application::getModel('PostMeta')
            ->setPostId($this->_postId);

        $custom = (bool) $meta->getValue('custom');

        if ($custom) {
            foreach ($this->getElements() as $key=>$elem) {
                if ('custom' == $key) {
                    continue;
                }

                $elem->setValue($meta->getValue($key));
            }
        }

        $this->_setCustom($custom);

        return $this;
    }

    public function save()
    {
        $meta = Ali_Application::getModel('PostMeta')
            ->setPostId($this->_postId);

        $custom = (bool) $this->getValue('custom');

        foreach ($this->getElements() as $key=>$elem) {
            if ($custom || 'custom' == $key) {
                $meta->setValue($key, $elem->getValue());
            } else {
                $meta->unsetValue($key);
            }
        }
    }

    protected function _setCustom($custom)
    {
        $this->setDefault('custom', $custom);

        $options = Ali_Application::getModel('Options');

        foreach ($this->getElements() as $key=>$elem) {
            if ('custom' == $key) {
                continue;
            }

            $elem->setAttrib('disabled', !$custom);
            if (!$custom) {
                $elem->setValue($options->getValue($key));
            }

        }
    }

    //
    // Getters & setters
    //

    public function setPost($post)
    {
        $this->_setPostId($post->ID);

        $postTypes = Ali_Application::getModel('PostType')->getList();
        $postType = strtolower($postTypes[$post->post_type]);

        foreach ($this->getElements() as $key=>$elem) {
            $elem->setLabel(str_replace('post/page', $postType, $elem->getLabel()));
        }

        return $this;
    }

    protected function _setPostId($value)
    {
        $this->_postId = $value;

        return $this;
    }

    public function getPostId()
    {
        return $this->_postId;
    }
}